package com.naz.sdkdemo;

import android.app.Application;
import android.content.Context;
import android.util.Log;

import com.clj.fastble.BleManager;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.interceptor.HttpLoggingInterceptor;
import com.lzy.okgo.model.HttpHeaders;
import com.naz.sdkdemo.utils.ContextUtil;
import com.naz.sdkdemo.weight.XToast;
import com.scwang.smartrefresh.layout.SmartRefreshLayout;
import com.scwang.smartrefresh.layout.api.DefaultRefreshFooterCreator;
import com.scwang.smartrefresh.layout.api.DefaultRefreshHeaderCreator;
import com.scwang.smartrefresh.layout.api.RefreshFooter;
import com.scwang.smartrefresh.layout.api.RefreshHeader;
import com.scwang.smartrefresh.layout.api.RefreshLayout;
import com.scwang.smartrefresh.layout.footer.ClassicsFooter;
import com.scwang.smartrefresh.layout.header.ClassicsHeader;
import com.tencent.bugly.crashreport.CrashReport;
import com.tencent.smtt.sdk.QbSdk;

import net.posprinter.IConnectListener;
import net.posprinter.IDeviceConnection;
import net.posprinter.POSConnect;

import java.util.List;
import java.util.logging.Level;

import androidx.multidex.MultiDex;
import okhttp3.OkHttpClient;

/**
 * Description:
 * Author: ydd
 * Date:2020/10/22
 */
public class BaseApplication extends Application {
    private static BaseApplication application;

    static {
        //设置全局的Header构建器
        SmartRefreshLayout.setDefaultRefreshHeaderCreator(new DefaultRefreshHeaderCreator() {
            @Override
            public RefreshHeader createRefreshHeader(Context context, RefreshLayout layout) {
                ClassicsHeader classicsHeader = new ClassicsHeader(context);
                return classicsHeader;////指定为经典Header，默认是 贝塞尔雷达Header
            }
        });
        //设置全局的Footer构建器
        SmartRefreshLayout.setDefaultRefreshFooterCreator(new DefaultRefreshFooterCreator() {
            @Override
            public RefreshFooter createRefreshFooter(Context context, RefreshLayout layout) {
                //指定为经典Footer，默认是 BallPulseFooter
                return new ClassicsFooter(context).setDrawableSize(20);
            }
        });
    }

    private IConnectListener connectListener = new IConnectListener() {
        @Override
        public void onStatus(int code, String connInfo, String msg) {
            switch (code){
                case POSConnect.CONNECT_SUCCESS:
                    Log.e("-------->","------>CONNECT_SUCCESS");
                    break;
                case POSConnect.CONNECT_FAIL:
                    Log.e("-------->","------>CONNECT_FAIL");
                    break;
                case POSConnect.CONNECT_INTERRUPT:
                    break;
                case POSConnect.SEND_FAIL:
                    break;
                case POSConnect.USB_DETACHED:
                    Log.e("-------->","------>USB_DETACHED");
                    break;
                case POSConnect.USB_ATTACHED:
                    Log.e("-------->","------>USB_ATTACHED");
                    break;
            }
        }
    };

    IDeviceConnection curConnect = null;
    @Override
    public void onCreate() {
        super.onCreate();
        application = this;
        ContextUtil.setmCtx(this);
//        CrashReport.initCrashReport(this, "90bf189bd4", false);
        initHttp();

        initWebview();
        POSConnect.init(this);

        connectUSB(searchUsb());
        MultiDex.install(this);
        BleManager.getInstance().init(getApplication());
        BleManager.getInstance()
                .enableLog(true)
                .setReConnectCount(1, 5000)
                .setSplitWriteNum(20)
                .setConnectOverTime(10000)
                .setOperateTimeout(5000);
    }

    private void initWebview() {
        QbSdk.PreInitCallback cb = new QbSdk.PreInitCallback() {
            @Override
            public void onViewInitFinished(boolean arg0) {
                //x5內核初始化完成的回调，为true表示x5内核加载成功，否则表示x5内核加载失败，会自动切换到系统内核。
                Log.d("app", "腾讯X5内核初始化回调 onViewInitFinished is " + arg0);
            }
            @Override
            public void onCoreInitFinished() {
                Log.d("app", "腾讯X5内核初始化回调 onCoreInitFinished");
            }
        };
        //x5内核初始化接口
        QbSdk.initX5Environment(getApplicationContext(), cb);
    }

    private String searchUsb() {
        List<String> usbNames = POSConnect.getUsbDevices(this);
//        XToast.showToast("usbNames="+usbNames.size());
        String ret = "";
        if (usbNames.size()>0) {
            ret = usbNames.get(0);
        }
        Log.e("-------->","------>ret="+ret);
        return ret;
    }

    private void connectUSB(String pathName){
        if (curConnect!=null){
            curConnect.close();
        }
        curConnect = POSConnect.createDevice(POSConnect.DEVICE_TYPE_USB);
        curConnect.connect(pathName, connectListener);
    }

    private void initHttp() {
        HttpHeaders headers = new HttpHeaders();
        headers.put("platform", "android");
        //XToast.showToast(SPUtils.getString("TOKEN"));
        //log相关
        HttpLoggingInterceptor loggingInterceptor = new HttpLoggingInterceptor("OkGo");
        if (AppConfig.IS_DEBUG) {
            loggingInterceptor.setPrintLevel(HttpLoggingInterceptor.Level.BODY);        //log打印级别，决定了log显示的详细程度
        } else {
            loggingInterceptor.setPrintLevel(HttpLoggingInterceptor.Level.NONE);
        }
        loggingInterceptor.setColorLevel(Level.INFO);

        OkGo.getInstance().init(this) //必须调用初始化
                .setOkHttpClient(new OkHttpClient.Builder()
                        .addInterceptor(loggingInterceptor).build())
                .addCommonHeaders(headers);
    }

    public static BaseApplication getApplication() {
        return application;
    }
}
